function [t2,bio_,nuc_,coal_,ccgt_,wind_,french_,dutch_,scot_,north_,...
    irish_,ew_,hydro_,pumped_,solar_,Pd_] = coarsen_data(output,year0,Dt)
%[t2,bio_,nuc_,coal_,ccgt_,wind_,french_,dutch_,scot_,north_,...
%irish_,ew_,hydro_,pumped_,solar_,Pd_] = coarsen_data(output,year0,Dt)
%     averages generation data from year0 (2017) to resolution Dt (1/2-h)
%     outputs arrays for each generation type, as well as time array t2,
%     and demand array Pd_.

% load('gridwatch_2012_2018_data','output')
% Dt = 1/2;
% year0=2017;
tstart = max([1,length(output.timestamp)-8760*12*(2018-year0)]);
tend = min([length(output.timestamp)-8760*12*(2017-year0)+1000,...
              length(output.timestamp)]);

t1 = output.timestamp(tstart:tend);
demand = output.demand(tstart:tend);
bio = output.biomass(tstart:tend);
nuc = output.nuclear(tstart:tend);
coal = output.coal(tstart:tend);
ccgt = output.ccgt(tstart:tend);
wind = output.wind(tstart:tend);
french = output.french_ict(tstart:tend);
dutch = output.dutch_ict(tstart:tend);
hydro = output.hydro(tstart:tend);
pumped = output.pumped(tstart:tend);
% the following are not used - insignificant, or netted off in the case of
% solar PV
scot = output.scotland_england(tstart:tend);
north = output.north_south(tstart:tend);
irish = output.irish_ict(tstart:tend);
ew = output.ew_ict(tstart:tend);
other = output.oil(tstart:tend)+output.ocgt(tstart:tend)+...
    output.other(tstart:tend); % no more OCGT since 2016
solar = output.solar(tstart:tend);

N = floor(8760/Dt);
bio_ = zeros(1,N);
nuc_ = zeros(1,N);
coal_ = zeros(1,N);
ccgt_ = zeros(1,N);
wind_ = zeros(1,N);
french_ = zeros(1,N);
dutch_ = zeros(1,N);
scot_ = zeros(1,N);
north_ = zeros(1,N);
irish_ = zeros(1,N);
ew_ = zeros(1,N);
hydro_ = zeros(1,N);
pumped_ = zeros(1,N);
solar_ = zeros(1,N);
Pd_ = zeros(1,N);

for nt = 1:N
    t2(nt) = datetime(year0,1,1,0,0,0)+duration([(nt-1)*Dt,0,0]);  % 'now'
    [~,t__1] = min(abs(t1-t2(nt))); % index of t1 that is closest to 'now'
    % and index of t1 that is closest to 'next'
    [~,t__2] = min( abs( t1-( t2(nt)+duration([Dt,0,0]) ) ) );
    bio_(nt) = mean(bio(t__1:t__2));
    nuc_(nt) = mean(nuc(t__1:t__2));
    coal_(nt) = mean(coal(t__1:t__2));
    ccgt_(nt) = mean(ccgt(t__1:t__2));
    wind_(nt) = mean(wind(t__1:t__2));
    french_(nt) = mean(french(t__1:t__2));
    dutch_(nt) = mean(dutch(t__1:t__2));
    scot_(nt) = mean(scot(t__1:t__2));
    north_(nt) = mean(north(t__1:t__2));
    irish_(nt) = mean(irish(t__1:t__2));
    ew_(nt) = mean(ew(t__1:t__2));
    hydro_(nt) = mean(hydro(t__1:t__2));
    pumped_(nt) = mean(pumped(t__1:t__2));
    solar_(nt) = mean(solar(t__1:t__2));
    Pd_(nt) = mean(demand(t__1:t__2));
end

end

